import { SchemaBlueprint, SchemaFieldDefinition, ValidationRules } from '../models/ExtendedSchemaTypes';
import { FailedValidation, SuccessfulValidation } from '../models/ValidationResults';
declare type addFieldOptions<T = any> = {
    callback?: (value: T) => boolean;
    undefined?: 'allow' | 'forbid';
};
export declare class ExtendedSchema<ImpliedType> implements SchemaBlueprint<ImpliedType> {
    private readonly fields;
    private readonly rules;
    constructor(rules?: ValidationRules);
    addField(key: string, type: SchemaFieldDefinition): void;
    addExtendedSchemaField(key: string, schema: SchemaBlueprint<any>, callback?: (value: any) => boolean, allowUndefined?: boolean): void;
    check(value: Record<string, unknown>): SuccessfulValidation<ImpliedType> | FailedValidation;
    length(): number;
    addStringField(key: string, options?: addFieldOptions<string>): void;
    addNumberField(key: string, options?: addFieldOptions<number>): void;
    addBooleanField(key: string, options?: addFieldOptions<boolean>): void;
    addArrayField(key: string, options?: addFieldOptions<Array<any>>): void;
    addEmailField(key: string, options?: addFieldOptions<string>): void;
    addRegexField(key: string, regex: RegExp, options?: addFieldOptions<string>): void;
    addFalsyField(key: string, options?: addFieldOptions<boolean>): void;
    addTruthyField(key: string, options?: addFieldOptions<boolean>): void;
    addArrayOfElementsField<K>(key: string, elementSchema: SchemaBlueprint<K>, options?: addFieldOptions<Array<K>>): void;
}
export {};
